# Changelog for `wikiquote`
## **0.1.18** - 06/01/2026
- Dropped support for Python 3.8 (3.9 is now the minimum).
- Fixed QOTD for English language.
- Clean up QOTD text for Spanish language before returning it.
- Fixed 401 errors on Wikiquote API usage.
- Use HTTPS URL for Wikiquote API.
- Switch to `uv` for dependency management.

## **0.1.17** - 20/08/2023
- Dropped support for Python 3.6 and 3.7 (3.8 is now the minimum).

## **0.1.16** - 28/07/2021
- Added support for Basque language.
- Fixed QOTD for French language (added secondary extraction method).
- Added the `MissingQOTDException` class, used to signal errors when retrieving the quote of the day.

## **0.1.15** - 03/05/2021
- Added support for Hebrew language.
- Dropped support for Python 3.4 and 3.5.
- Fixed QOTD for Italian language.

## **0.1.14** - 09/07/2019
- Internal improvements.

## **0.1.13** - 07/07/2019
- Added support for Portuguese language.
- Added `qotd()` function.
- Set `wikiquote`'s `__all__` variable.

## **0.1.12** - 16/04/2019
- Added support for Polish language.
- Fixed non-breaking spaces appearing in extracted French quotes.

## **0.1.11** - 18/09/2018
- Fixed French QOTD.

## **0.1.10** - 12/09/2018
- _(This release was not published)_.

## **0.1.9** - 03/09/2018
- Updated package description.

## **0.1.8** - 03/09/2018
- Fixed French quotes extraction not working correctly.

## **0.1.7** - 07/04/2018
- Added support for Italian language.
- Improved general quote extraction function.

## **0.1.6** - 24/12/2017
- Added support for German language.
- _(This release was not published)_.

## **0.1.5** - 28/02/2017
- Small post-release bug fix.

## **0.1.4** - 09/04/2016
- Added random titles function.
- Improved general quote extraction function.
- Added support for Spanish language.

## **0.1.3** - 18/03/2016
- Added supported languages function.
- Fixed French QOTD.

## **0.1.2** - 14/12/2015
- Added support for French language.
- Misc. bug fixes.

## **0.1.1** - 26/02/2015
- Initial release with support for Python 3.4+.
